package cn.estsh.i3plus.ext.mes.pcn.apiservice.serviceimpl.station.function;

import cn.estsh.i3plus.ext.mes.pcn.api.busi.IMesProductionDispatchContextStepService;
import cn.estsh.i3plus.ext.mes.pcn.pojo.util.MesPcnExtConstWords;
import cn.estsh.i3plus.mes.pcn.serviceimpl.fsm.BaseSwsService;
import cn.estsh.i3plus.mes.pcn.serviceimpl.fsm.IShippingDispatchService;
import cn.estsh.i3plus.mes.pcn.serviceimpl.fsm.function.IFsmModuleFunctionService;
import cn.estsh.i3plus.platform.common.util.MesPcnConstWords;
import cn.estsh.i3plus.pojo.base.enumutil.MesPcnEnumUtil;
import cn.estsh.i3plus.pojo.mes.model.ButtonDynamicModel;
import cn.estsh.i3plus.pojo.mes.model.StationRequestBean;
import cn.estsh.i3plus.pojo.mes.model.StationResultBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

/**
 * @Description : 工位参数按钮事件接口实现【选择工单】
 **/
@Service
public class MesFunctionChooseWorkOrderService extends BaseSwsService implements IFsmModuleFunctionService {

    @Autowired
    private IMesProductionDispatchContextStepService productionDispatchContextStepService;

    @Autowired
    private IShippingDispatchService shippingDispatchService;

    @Override
    public boolean doFunction(StationRequestBean reqBean, StationResultBean resultBean, ButtonDynamicModel buttonDynamicModel) {

        if (!checkCavityOrderIsValid(buttonDynamicModel.getFunctionValue())) {
            this.sendMessage(reqBean, resultBean.writeDbLog(), String.format("生产线[%s]工位[%s]%s失败,请检查选择的工单信息[%s]的有效性!",
                    reqBean.getWorkCenterCode(), reqBean.getWorkCellCode(), buttonDynamicModel.getButtonName(), buttonDynamicModel.getFunctionValue()), MesPcnEnumUtil.STATION_BUSI_TYPE.MESSAGE, MesPcnEnumUtil.STATION_DATA_TYPE.EXP_TEXT);
            return false;
        }

        //保存手动选择的腔数及工单信息上下文
        productionDispatchContextStepService.saveFunctionChooseCavityOrderContext(reqBean, buttonDynamicModel.getFunctionValue());

        reqBean.setClientInfo(shippingDispatchService.getActorClientInfo(reqBean));
        reqBean.setInterfaceType(MesPcnConstWords.SHIPPING);
        reqBean.setBusiType(MesPcnConstWords.WS_CMD_DO_SCAN);
        reqBean.setTriggerAutoFsm(true);

        shippingDispatchService.doSendScanQueueIfNoQueue(reqBean, false);

        return true;

    }

    //腔数=工单个数   数据格式:   腔数;工单1;工单2;工单3
    private Boolean checkCavityOrderIsValid(String functionValue) {

        if (StringUtils.isEmpty(functionValue)) return false;

        String[] value = functionValue.split(MesPcnExtConstWords.SEMICOLON);

        if (null == value) return false;

        try {

            Integer cavity = Integer.valueOf(value[0]);

            if (cavity != value.length - 1) return false;

        } catch (NumberFormatException e) {

            return false;

        }

        return true;


    }

}
